from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.sales import flow_pb2 as _flow_pb2
from omni.pro.protos.v1.sales import state_pb2 as _state_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Transition(_message.Message):
    __slots__ = [
        "id",
        "flow",
        "source_state",
        "destination_state",
        "trigger",
        "description",
        "logic",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    FLOW_FIELD_NUMBER: _ClassVar[int]
    SOURCE_STATE_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_STATE_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LOGIC_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    flow: _flow_pb2.Flow
    source_state: _state_pb2.State
    destination_state: _state_pb2.State
    trigger: str
    description: str
    logic: str
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        flow: _Optional[_Union[_flow_pb2.Flow, _Mapping]] = ...,
        source_state: _Optional[_Union[_state_pb2.State, _Mapping]] = ...,
        destination_state: _Optional[_Union[_state_pb2.State, _Mapping]] = ...,
        trigger: _Optional[str] = ...,
        description: _Optional[str] = ...,
        logic: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class TransitionCreateRequest(_message.Message):
    __slots__ = ["flow_id", "source_state_id", "destination_state_id", "trigger", "description", "logic", "context"]
    FLOW_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_STATE_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_STATE_ID_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LOGIC_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    flow_id: int
    source_state_id: int
    destination_state_id: int
    trigger: str
    description: str
    logic: str
    context: _base_pb2.Context
    def __init__(
        self,
        flow_id: _Optional[int] = ...,
        source_state_id: _Optional[int] = ...,
        destination_state_id: _Optional[int] = ...,
        trigger: _Optional[str] = ...,
        description: _Optional[str] = ...,
        logic: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TransitionCreateResponse(_message.Message):
    __slots__ = ["transition", "response_standard"]
    TRANSITION_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    transition: Transition
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        transition: _Optional[_Union[Transition, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class TransitionReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TransitionReadResponse(_message.Message):
    __slots__ = ["transitions", "meta_data", "response_standard"]
    TRANSITIONS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    transitions: _containers.RepeatedCompositeFieldContainer[Transition]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        transitions: _Optional[_Iterable[_Union[Transition, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class TransitionUpdateRequest(_message.Message):
    __slots__ = ["transition", "context"]
    TRANSITION_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    transition: Transition
    context: _base_pb2.Context
    def __init__(
        self,
        transition: _Optional[_Union[Transition, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TransitionUpdateResponse(_message.Message):
    __slots__ = ["transition", "response_standard"]
    TRANSITION_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    transition: Transition
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        transition: _Optional[_Union[Transition, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class TransitionDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class TransitionDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/stock_security_product.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%v1/rules/stock_security_product.proto\x12\x30pro.omni.oms.api.v1.rules.stock_security_product\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto"\xe0\x01\n\x14StockSecurityProduct\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12%\n\x04skus\x18\x05 \x03(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xac\x01\n!StockSecurityProductCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12%\n\x04skus\x18\x04 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd7\x01\n"StockSecurityProductCreateResponse\x12\x66\n\x16stock_security_product\x18\x01 \x01(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfd\x02\n\x1fStockSecurityProductReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x02\n StockSecurityProductReadResponse\x12g\n\x17stock_security_products\x18\x01 \x03(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xc3\x01\n!StockSecurityProductUpdateRequest\x12\x66\n\x16stock_security_product\x18\x01 \x01(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd7\x01\n"StockSecurityProductUpdateResponse\x12\x66\n\x16stock_security_product\x18\x01 \x01(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"g\n!StockSecurityProductDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"o\n"StockSecurityProductDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc7\x06\n\x1bStockSecurityProductService\x12\xc9\x01\n\x1aStockSecurityProductCreate\x12S.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductCreateRequest\x1aT.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductCreateResponse"\x00\x12\xc3\x01\n\x18StockSecurityProductRead\x12Q.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductReadRequest\x1aR.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductReadResponse"\x00\x12\xc9\x01\n\x1aStockSecurityProductUpdate\x12S.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductUpdateRequest\x1aT.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductUpdateResponse"\x00\x12\xc9\x01\n\x1aStockSecurityProductDelete\x12S.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductDeleteRequest\x1aT.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.stock_security_product_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STOCKSECURITYPRODUCT"]._serialized_start = 173
    _globals["_STOCKSECURITYPRODUCT"]._serialized_end = 397
    _globals["_STOCKSECURITYPRODUCTCREATEREQUEST"]._serialized_start = 400
    _globals["_STOCKSECURITYPRODUCTCREATEREQUEST"]._serialized_end = 572
    _globals["_STOCKSECURITYPRODUCTCREATERESPONSE"]._serialized_start = 575
    _globals["_STOCKSECURITYPRODUCTCREATERESPONSE"]._serialized_end = 790
    _globals["_STOCKSECURITYPRODUCTREADREQUEST"]._serialized_start = 793
    _globals["_STOCKSECURITYPRODUCTREADREQUEST"]._serialized_end = 1174
    _globals["_STOCKSECURITYPRODUCTREADRESPONSE"]._serialized_start = 1177
    _globals["_STOCKSECURITYPRODUCTREADRESPONSE"]._serialized_end = 1450
    _globals["_STOCKSECURITYPRODUCTUPDATEREQUEST"]._serialized_start = 1453
    _globals["_STOCKSECURITYPRODUCTUPDATEREQUEST"]._serialized_end = 1648
    _globals["_STOCKSECURITYPRODUCTUPDATERESPONSE"]._serialized_start = 1651
    _globals["_STOCKSECURITYPRODUCTUPDATERESPONSE"]._serialized_end = 1866
    _globals["_STOCKSECURITYPRODUCTDELETEREQUEST"]._serialized_start = 1868
    _globals["_STOCKSECURITYPRODUCTDELETEREQUEST"]._serialized_end = 1971
    _globals["_STOCKSECURITYPRODUCTDELETERESPONSE"]._serialized_start = 1973
    _globals["_STOCKSECURITYPRODUCTDELETERESPONSE"]._serialized_end = 2084
    _globals["_STOCKSECURITYPRODUCTSERVICE"]._serialized_start = 2087
    _globals["_STOCKSECURITYPRODUCTSERVICE"]._serialized_end = 2926
# @@protoc_insertion_point(module_scope)



import grpc


class LoggingInterceptor(grpc.ServerInterceptor):
    """
    Interceptor to log the gRPC method calls.
    Interceptor para registrar las llamadas de métodos gRPC.
    """

    def __init__(self, logger):
        """
        Initializes the LoggingInterceptor with a logger.
        Inicializa el LoggingInterceptor con un registrador.

        Args:
        logger (object): The logger instance used for logging.
                         Instancia de registrador utilizada para registrar.
        """
        self.logger = logger

    def intercept_service(self, continuation, handler_call_details):
        """
        Intercept the gRPC service call and log the method being called.
        Intercepta la llamada de servicio gRPC y registra el método que se está llamando.

        Args:
        continuation (function): A function that proceeds to the next interceptor or the service handler.
                                 Una función que procede al siguiente interceptor o al manejador del servicio.
        handler_call_details (obj): A named tuple with the attributes 'method' and 'invocation_metadata'.
                                    Una tupla nombrada con los atributos 'method' y 'invocation_metadata'.

        Returns:
        (obj): The result of the continuation function.
               El resultado de la función continuation.

        Raises:
        Exception: Propagates any exception raised during the gRPC service invocation.
                   Propaga cualquier excepción generada durante la invocación del servicio gRPC.
        """
        try:
            # Optional: Log the source of the call. Remove if not needed.
            # client_ip = handler_call_details.invocation_metadata["client_ip"]
            # self.logger.info("Received call from %s to %s", client_ip, handler_call_details.method)
            if handler_call_details.method != "/AWS.ALB/healthcheck":
                self.logger.info("Received call to %s", handler_call_details.method)
                return continuation(handler_call_details)
        except Exception as e:
            self.logger.error("Error while invoking method %s: %s", handler_call_details.method, str(e))
            raise



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import attachment_pb2 as v1_dot_stock_dot_attachment__pb2


class AttachmentServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AttachmentCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentCreate",
            request_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentCreateResponse.FromString,
        )
        self.AttachmentRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentRead",
            request_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentReadResponse.FromString,
        )
        self.AttachmentUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentUpdate",
            request_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentUpdateResponse.FromString,
        )
        self.AttachmentDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentDelete",
            request_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentDeleteResponse.FromString,
        )


class AttachmentServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AttachmentCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AttachmentDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AttachmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "AttachmentCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentCreate,
            request_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentCreateResponse.SerializeToString,
        ),
        "AttachmentRead": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentRead,
            request_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentReadResponse.SerializeToString,
        ),
        "AttachmentUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentUpdate,
            request_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentUpdateResponse.SerializeToString,
        ),
        "AttachmentDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AttachmentDelete,
            request_deserializer=v1_dot_stock_dot_attachment__pb2.AttachmentDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_attachment__pb2.AttachmentDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.attachment.AttachmentService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class AttachmentService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AttachmentCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentCreate",
            v1_dot_stock_dot_attachment__pb2.AttachmentCreateRequest.SerializeToString,
            v1_dot_stock_dot_attachment__pb2.AttachmentCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentRead",
            v1_dot_stock_dot_attachment__pb2.AttachmentReadRequest.SerializeToString,
            v1_dot_stock_dot_attachment__pb2.AttachmentReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentUpdate",
            v1_dot_stock_dot_attachment__pb2.AttachmentUpdateRequest.SerializeToString,
            v1_dot_stock_dot_attachment__pb2.AttachmentUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AttachmentDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.attachment.AttachmentService/AttachmentDelete",
            v1_dot_stock_dot_attachment__pb2.AttachmentDeleteRequest.SerializeToString,
            v1_dot_stock_dot_attachment__pb2.AttachmentDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_locality_matrix_values_pb2 as v1_dot_rules_dot_delivery__locality__matrix__values__pb2,
)


class DeliveryLocalityMatrixValuesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryLocalityMatrixValuesCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesCreate",
            request_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesCreateResponse.FromString,
        )
        self.DeliveryLocalityMatrixValuesRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesRead",
            request_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesReadResponse.FromString,
        )
        self.DeliveryLocalityMatrixValuesUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesUpdate",
            request_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesUpdateResponse.FromString,
        )
        self.DeliveryLocalityMatrixValuesDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesDelete",
            request_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesDeleteResponse.FromString,
        )


class DeliveryLocalityMatrixValuesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryLocalityMatrixValuesCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryLocalityMatrixValuesRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryLocalityMatrixValuesUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryLocalityMatrixValuesDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryLocalityMatrixValuesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryLocalityMatrixValuesCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityMatrixValuesCreate,
            request_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesCreateResponse.SerializeToString,
        ),
        "DeliveryLocalityMatrixValuesRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityMatrixValuesRead,
            request_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesReadResponse.SerializeToString,
        ),
        "DeliveryLocalityMatrixValuesUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityMatrixValuesUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesUpdateResponse.SerializeToString,
        ),
        "DeliveryLocalityMatrixValuesDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryLocalityMatrixValuesDelete,
            request_deserializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryLocalityMatrixValuesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryLocalityMatrixValuesCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesCreate",
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryLocalityMatrixValuesRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesRead",
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryLocalityMatrixValuesUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesUpdate",
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryLocalityMatrixValuesDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesService/DeliveryLocalityMatrixValuesDelete",
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__locality__matrix__values__pb2.DeliveryLocalityMatrixValuesDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import stock_security_product_pb2 as v1_dot_rules_dot_stock__security__product__pb2


class StockSecurityProductServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StockSecurityProductCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductCreate",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateResponse.FromString,
        )
        self.StockSecurityProductRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductRead",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadResponse.FromString,
        )
        self.StockSecurityProductUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductUpdate",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateResponse.FromString,
        )
        self.StockSecurityProductDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductDelete",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteResponse.FromString,
        )


class StockSecurityProductServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StockSecurityProductCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityProductRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityProductUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityProductDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StockSecurityProductServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StockSecurityProductCreate": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductCreate,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateResponse.SerializeToString,
        ),
        "StockSecurityProductRead": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductRead,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadResponse.SerializeToString,
        ),
        "StockSecurityProductUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductUpdate,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateResponse.SerializeToString,
        ),
        "StockSecurityProductDelete": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductDelete,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StockSecurityProductService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StockSecurityProductCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductCreate",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityProductRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductRead",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityProductUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductUpdate",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityProductDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductDelete",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/document_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/utilities/document_type.proto\x12+pro.omni.oms.api.v1.utilities.document_type\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xdd\x01\n\x0c\x44ocumentType\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x05\x12*\n\x06is_vat\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xd2\x01\n\x16\x44ocumentTypeAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12*\n\x06is_vat\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb6\x01\n\x17\x44ocumentTypeAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rdocument_type\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType"\xf5\x02\n\x17\x44ocumentTypeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf3\x01\n\x18\x44ocumentTypeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12Q\n\x0e\x64ocument_types\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType"\xa5\x01\n\x19\x44ocumentTypeUpdateRequest\x12P\n\rdocument_type\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1a\x44ocumentTypeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rdocument_type\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType"_\n\x19\x44ocumentTypeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1a\x44ocumentTypeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xae\x05\n\x13\x44ocumentTypeService\x12\x9e\x01\n\x0f\x44ocumentTypeAdd\x12\x43.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeAddRequest\x1a\x44.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeAddResponse"\x00\x12\xa1\x01\n\x10\x44ocumentTypeRead\x12\x44.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeReadRequest\x1a\x45.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeReadResponse"\x00\x12\xa7\x01\n\x12\x44ocumentTypeUpdate\x12\x46.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeUpdateRequest\x1aG.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeUpdateResponse"\x00\x12\xa7\x01\n\x12\x44ocumentTypeDelete\x12\x46.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeDeleteRequest\x1aG.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.document_type_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DOCUMENTTYPE"]._serialized_start = 133
    _globals["_DOCUMENTTYPE"]._serialized_end = 354
    _globals["_DOCUMENTTYPEADDREQUEST"]._serialized_start = 357
    _globals["_DOCUMENTTYPEADDREQUEST"]._serialized_end = 567
    _globals["_DOCUMENTTYPEADDRESPONSE"]._serialized_start = 570
    _globals["_DOCUMENTTYPEADDRESPONSE"]._serialized_end = 752
    _globals["_DOCUMENTTYPEREADREQUEST"]._serialized_start = 755
    _globals["_DOCUMENTTYPEREADREQUEST"]._serialized_end = 1128
    _globals["_DOCUMENTTYPEREADRESPONSE"]._serialized_start = 1131
    _globals["_DOCUMENTTYPEREADRESPONSE"]._serialized_end = 1374
    _globals["_DOCUMENTTYPEUPDATEREQUEST"]._serialized_start = 1377
    _globals["_DOCUMENTTYPEUPDATEREQUEST"]._serialized_end = 1542
    _globals["_DOCUMENTTYPEUPDATERESPONSE"]._serialized_start = 1545
    _globals["_DOCUMENTTYPEUPDATERESPONSE"]._serialized_end = 1730
    _globals["_DOCUMENTTYPEDELETEREQUEST"]._serialized_start = 1732
    _globals["_DOCUMENTTYPEDELETEREQUEST"]._serialized_end = 1827
    _globals["_DOCUMENTTYPEDELETERESPONSE"]._serialized_start = 1829
    _globals["_DOCUMENTTYPEDELETERESPONSE"]._serialized_end = 1932
    _globals["_DOCUMENTTYPESERVICE"]._serialized_start = 1935
    _globals["_DOCUMENTTYPESERVICE"]._serialized_end = 2621
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import payment_method_pb2 as v1_dot_utilities_dot_payment__method__pb2


class PaymentMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PaymentMethodAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodAdd",
            request_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodAddResponse.FromString,
        )
        self.PaymentMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodRead",
            request_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodReadResponse.FromString,
        )
        self.PaymentMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodUpdate",
            request_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodUpdateResponse.FromString,
        )
        self.PaymentMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodDelete",
            request_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodDeleteResponse.FromString,
        )


class PaymentMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PaymentMethodAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PaymentMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PaymentMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PaymentMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PaymentMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PaymentMethodAdd": grpc.unary_unary_rpc_method_handler(
            servicer.PaymentMethodAdd,
            request_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodAddResponse.SerializeToString,
        ),
        "PaymentMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.PaymentMethodRead,
            request_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodReadResponse.SerializeToString,
        ),
        "PaymentMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PaymentMethodUpdate,
            request_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodUpdateResponse.SerializeToString,
        ),
        "PaymentMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PaymentMethodDelete,
            request_deserializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_payment__method__pb2.PaymentMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PaymentMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PaymentMethodAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodAdd",
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodAddRequest.SerializeToString,
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PaymentMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodRead",
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodReadRequest.SerializeToString,
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PaymentMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodUpdate",
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PaymentMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodService/PaymentMethodDelete",
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_payment__method__pb2.PaymentMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/currency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/sales/currency.proto\x12"pro.omni.oms.api.v1.sales.currency\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb8\x01\n\x08\x43urrency\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x17\n\x0f\x63urrency_doc_id\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x84\x01\n\x15\x43urrencyCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x17\n\x0f\x63urrency_doc_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43urrencyCreateResponse\x12>\n\x08\x63urrency\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.sales.currency.Currency\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13\x43urrencyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xde\x01\n\x14\x43urrencyReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12@\n\ncurrencies\x18\x03 \x03(\x0b\x32,.pro.omni.oms.api.v1.sales.currency.Currency"\x8f\x01\n\x15\x43urrencyUpdateRequest\x12>\n\x08\x63urrency\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.sales.currency.Currency\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43urrencyUpdateResponse\x12>\n\x08\x63urrency\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.sales.currency.Currency\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15\x43urrencyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16\x43urrencyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0f\x43urrencyService\x12\x89\x01\n\x0e\x43urrencyCreate\x12\x39.pro.omni.oms.api.v1.sales.currency.CurrencyCreateRequest\x1a:.pro.omni.oms.api.v1.sales.currency.CurrencyCreateResponse"\x00\x12\x83\x01\n\x0c\x43urrencyRead\x12\x37.pro.omni.oms.api.v1.sales.currency.CurrencyReadRequest\x1a\x38.pro.omni.oms.api.v1.sales.currency.CurrencyReadResponse"\x00\x12\x89\x01\n\x0e\x43urrencyUpdate\x12\x39.pro.omni.oms.api.v1.sales.currency.CurrencyUpdateRequest\x1a:.pro.omni.oms.api.v1.sales.currency.CurrencyUpdateResponse"\x00\x12\x89\x01\n\x0e\x43urrencyDelete\x12\x39.pro.omni.oms.api.v1.sales.currency.CurrencyDeleteRequest\x1a:.pro.omni.oms.api.v1.sales.currency.CurrencyDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.currency_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CURRENCY"]._serialized_start = 115
    _globals["_CURRENCY"]._serialized_end = 299
    _globals["_CURRENCYCREATEREQUEST"]._serialized_start = 302
    _globals["_CURRENCYCREATEREQUEST"]._serialized_end = 434
    _globals["_CURRENCYCREATERESPONSE"]._serialized_start = 437
    _globals["_CURRENCYCREATERESPONSE"]._serialized_end = 600
    _globals["_CURRENCYREADREQUEST"]._serialized_start = 603
    _globals["_CURRENCYREADREQUEST"]._serialized_end = 972
    _globals["_CURRENCYREADRESPONSE"]._serialized_start = 975
    _globals["_CURRENCYREADRESPONSE"]._serialized_end = 1197
    _globals["_CURRENCYUPDATEREQUEST"]._serialized_start = 1200
    _globals["_CURRENCYUPDATEREQUEST"]._serialized_end = 1343
    _globals["_CURRENCYUPDATERESPONSE"]._serialized_start = 1346
    _globals["_CURRENCYUPDATERESPONSE"]._serialized_end = 1509
    _globals["_CURRENCYDELETEREQUEST"]._serialized_start = 1511
    _globals["_CURRENCYDELETEREQUEST"]._serialized_end = 1602
    _globals["_CURRENCYDELETERESPONSE"]._serialized_start = 1604
    _globals["_CURRENCYDELETERESPONSE"]._serialized_end = 1703
    _globals["_CURRENCYSERVICE"]._serialized_start = 1706
    _globals["_CURRENCYSERVICE"]._serialized_end = 2277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.sales import client_pb2 as v1_dot_sales_dot_client__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/sales/address.proto\x12!pro.omni.oms.api.v1.sales.address\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x15v1/sales/client.proto"\x86\x02\n\x07\x41\x64\x64ress\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x38\n\x06\x63lient\x18\x02 \x01(\x0b\x32(.pro.omni.oms.api.v1.sales.client.Client\x12\x16\n\x0e\x61\x64\x64ress_doc_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_code\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xab\x01\n\x14\x41\x64\x64ressCreateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x61\x64\x64ress_doc_id\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_code\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x41\x64\x64ressCreateResponse\x12;\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.address.Address\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf0\x02\n\x12\x41\x64\x64ressReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xda\x01\n\x13\x41\x64\x64ressReadResponse\x12=\n\taddresses\x18\x01 \x03(\x0b\x32*.pro.omni.oms.api.v1.sales.address.Address\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x14\x41\x64\x64ressUpdateRequest\x12;\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.address.Address\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x41\x64\x64ressUpdateResponse\x12;\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.address.Address\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"Z\n\x14\x41\x64\x64ressDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x41\x64\x64ressDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa5\x04\n\x0e\x41\x64\x64ressService\x12\x84\x01\n\rAddressCreate\x12\x37.pro.omni.oms.api.v1.sales.address.AddressCreateRequest\x1a\x38.pro.omni.oms.api.v1.sales.address.AddressCreateResponse"\x00\x12~\n\x0b\x41\x64\x64ressRead\x12\x35.pro.omni.oms.api.v1.sales.address.AddressReadRequest\x1a\x36.pro.omni.oms.api.v1.sales.address.AddressReadResponse"\x00\x12\x84\x01\n\rAddressUpdate\x12\x37.pro.omni.oms.api.v1.sales.address.AddressUpdateRequest\x1a\x38.pro.omni.oms.api.v1.sales.address.AddressUpdateResponse"\x00\x12\x84\x01\n\rAddressDelete\x12\x37.pro.omni.oms.api.v1.sales.address.AddressDeleteRequest\x1a\x38.pro.omni.oms.api.v1.sales.address.AddressDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.address_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ADDRESS"]._serialized_start = 136
    _globals["_ADDRESS"]._serialized_end = 398
    _globals["_ADDRESSCREATEREQUEST"]._serialized_start = 401
    _globals["_ADDRESSCREATEREQUEST"]._serialized_end = 572
    _globals["_ADDRESSCREATERESPONSE"]._serialized_start = 575
    _globals["_ADDRESSCREATERESPONSE"]._serialized_end = 734
    _globals["_ADDRESSREADREQUEST"]._serialized_start = 737
    _globals["_ADDRESSREADREQUEST"]._serialized_end = 1105
    _globals["_ADDRESSREADRESPONSE"]._serialized_start = 1108
    _globals["_ADDRESSREADRESPONSE"]._serialized_end = 1326
    _globals["_ADDRESSUPDATEREQUEST"]._serialized_start = 1329
    _globals["_ADDRESSUPDATEREQUEST"]._serialized_end = 1468
    _globals["_ADDRESSUPDATERESPONSE"]._serialized_start = 1471
    _globals["_ADDRESSUPDATERESPONSE"]._serialized_end = 1630
    _globals["_ADDRESSDELETEREQUEST"]._serialized_start = 1632
    _globals["_ADDRESSDELETEREQUEST"]._serialized_end = 1722
    _globals["_ADDRESSDELETERESPONSE"]._serialized_start = 1724
    _globals["_ADDRESSDELETERESPONSE"]._serialized_end = 1822
    _globals["_ADDRESSSERVICE"]._serialized_start = 1825
    _globals["_ADDRESSSERVICE"]._serialized_end = 2374
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13v1/stock/user.proto\x12\x1epro.omni.oms.api.v1.stock.user\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xa2\x01\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0buser_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"n\n\x11UserCreateRequest\x12\x13\n\x0buser_doc_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.user.User"\xed\x02\n\x0fUserReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n\x10UserReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x33\n\x05users\x18\x03 \x03(\x0b\x32$.pro.omni.oms.api.v1.stock.user.User"\x7f\n\x11UserUpdateRequest\x12\x32\n\x04user\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.user.User\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12UserUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.stock.user.User"W\n\x11UserDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12UserDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe3\x03\n\x0bUserService\x12u\n\nUserCreate\x12\x31.pro.omni.oms.api.v1.stock.user.UserCreateRequest\x1a\x32.pro.omni.oms.api.v1.stock.user.UserCreateResponse"\x00\x12o\n\x08UserRead\x12/.pro.omni.oms.api.v1.stock.user.UserReadRequest\x1a\x30.pro.omni.oms.api.v1.stock.user.UserReadResponse"\x00\x12u\n\nUserUpdate\x12\x31.pro.omni.oms.api.v1.stock.user.UserUpdateRequest\x1a\x32.pro.omni.oms.api.v1.stock.user.UserUpdateResponse"\x00\x12u\n\nUserDelete\x12\x31.pro.omni.oms.api.v1.stock.user.UserDeleteRequest\x1a\x32.pro.omni.oms.api.v1.stock.user.UserDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.user_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_USER"]._serialized_start = 107
    _globals["_USER"]._serialized_end = 269
    _globals["_USERCREATEREQUEST"]._serialized_start = 271
    _globals["_USERCREATEREQUEST"]._serialized_end = 381
    _globals["_USERCREATERESPONSE"]._serialized_start = 384
    _globals["_USERCREATERESPONSE"]._serialized_end = 531
    _globals["_USERREADREQUEST"]._serialized_start = 534
    _globals["_USERREADREQUEST"]._serialized_end = 899
    _globals["_USERREADRESPONSE"]._serialized_start = 902
    _globals["_USERREADRESPONSE"]._serialized_end = 1107
    _globals["_USERUPDATEREQUEST"]._serialized_start = 1109
    _globals["_USERUPDATEREQUEST"]._serialized_end = 1236
    _globals["_USERUPDATERESPONSE"]._serialized_start = 1239
    _globals["_USERUPDATERESPONSE"]._serialized_end = 1386
    _globals["_USERDELETEREQUEST"]._serialized_start = 1388
    _globals["_USERDELETEREQUEST"]._serialized_end = 1475
    _globals["_USERDELETERESPONSE"]._serialized_start = 1477
    _globals["_USERDELETERESPONSE"]._serialized_end = 1572
    _globals["_USERSERVICE"]._serialized_start = 1575
    _globals["_USERSERVICE"]._serialized_end = 2058
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/calculate_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(v1/rules/calculate_delivery_method.proto\x12+pro.omni.oms.api.v1.rules.delivery_coverage\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto"\xea\x01\n&CalculateDeliveryMethodCoverageRequest\x12-\n\x0c\x63\x61rt_details\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10shipping_details\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa0\x01\n\'CalculateDeliveryMethodCoverageResponse\x12*\n\x06result\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xee\x01\n*CalculateDeliveryMethodAvailabilityRequest\x12-\n\x0c\x63\x61rt_details\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10shipping_details\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa1\x01\n+CalculateDeliveryMethodAvailabilityResponse\x12\'\n\x06result\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe6\x01\n"CalculateDeliveryMethodTimeRequest\x12-\n\x0c\x63\x61rt_details\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10shipping_details\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9c\x01\n#CalculateDeliveryMethodTimeResponse\x12*\n\x06result\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe7\x01\n#CalculateDeliveryMethodPriceRequest\x12-\n\x0c\x63\x61rt_details\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10shipping_details\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x01\n$CalculateDeliveryMethodPriceResponse\x12*\n\x06result\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xdb\x06\n\x1e\x43\x61lculateDeliveryMethodService\x12\xce\x01\n\x1f\x43\x61lculateDeliveryMethodCoverage\x12S.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodCoverageRequest\x1aT.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodCoverageResponse"\x00\x12\xda\x01\n#CalculateDeliveryMethodAvailability\x12W.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodAvailabilityRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodAvailabilityResponse"\x00\x12\xc2\x01\n\x1b\x43\x61lculateDeliveryMethodTime\x12O.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodTimeRequest\x1aP.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodTimeResponse"\x00\x12\xc5\x01\n\x1c\x43\x61lculateDeliveryMethodPrice\x12P.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodPriceRequest\x1aQ.pro.omni.oms.api.v1.rules.delivery_coverage.CalculateDeliveryMethodPriceResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.calculate_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CALCULATEDELIVERYMETHODCOVERAGEREQUEST"]._serialized_start = 171
    _globals["_CALCULATEDELIVERYMETHODCOVERAGEREQUEST"]._serialized_end = 405
    _globals["_CALCULATEDELIVERYMETHODCOVERAGERESPONSE"]._serialized_start = 408
    _globals["_CALCULATEDELIVERYMETHODCOVERAGERESPONSE"]._serialized_end = 568
    _globals["_CALCULATEDELIVERYMETHODAVAILABILITYREQUEST"]._serialized_start = 571
    _globals["_CALCULATEDELIVERYMETHODAVAILABILITYREQUEST"]._serialized_end = 809
    _globals["_CALCULATEDELIVERYMETHODAVAILABILITYRESPONSE"]._serialized_start = 812
    _globals["_CALCULATEDELIVERYMETHODAVAILABILITYRESPONSE"]._serialized_end = 973
    _globals["_CALCULATEDELIVERYMETHODTIMEREQUEST"]._serialized_start = 976
    _globals["_CALCULATEDELIVERYMETHODTIMEREQUEST"]._serialized_end = 1206
    _globals["_CALCULATEDELIVERYMETHODTIMERESPONSE"]._serialized_start = 1209
    _globals["_CALCULATEDELIVERYMETHODTIMERESPONSE"]._serialized_end = 1365
    _globals["_CALCULATEDELIVERYMETHODPRICEREQUEST"]._serialized_start = 1368
    _globals["_CALCULATEDELIVERYMETHODPRICEREQUEST"]._serialized_end = 1599
    _globals["_CALCULATEDELIVERYMETHODPRICERESPONSE"]._serialized_start = 1602
    _globals["_CALCULATEDELIVERYMETHODPRICERESPONSE"]._serialized_end = 1759
    _globals["_CALCULATEDELIVERYMETHODSERVICE"]._serialized_start = 1762
    _globals["_CALCULATEDELIVERYMETHODSERVICE"]._serialized_end = 2621
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import order_line_pb2 as v1_dot_sales_dot_order__line__pb2


class OrderLineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.OrderLineCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineCreate",
            request_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineCreateResponse.FromString,
        )
        self.OrderLineRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineRead",
            request_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineReadResponse.FromString,
        )
        self.OrderLineUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineUpdate",
            request_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineUpdateResponse.FromString,
        )
        self.OrderLineDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineDelete",
            request_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineDeleteResponse.FromString,
        )


class OrderLineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def OrderLineCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OrderLineRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OrderLineUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OrderLineDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_OrderLineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "OrderLineCreate": grpc.unary_unary_rpc_method_handler(
            servicer.OrderLineCreate,
            request_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineCreateResponse.SerializeToString,
        ),
        "OrderLineRead": grpc.unary_unary_rpc_method_handler(
            servicer.OrderLineRead,
            request_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineReadResponse.SerializeToString,
        ),
        "OrderLineUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.OrderLineUpdate,
            request_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineUpdateResponse.SerializeToString,
        ),
        "OrderLineDelete": grpc.unary_unary_rpc_method_handler(
            servicer.OrderLineDelete,
            request_deserializer=v1_dot_sales_dot_order__line__pb2.OrderLineDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_order__line__pb2.OrderLineDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.order.line.OrderLineService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class OrderLineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def OrderLineCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineCreate",
            v1_dot_sales_dot_order__line__pb2.OrderLineCreateRequest.SerializeToString,
            v1_dot_sales_dot_order__line__pb2.OrderLineCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OrderLineRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineRead",
            v1_dot_sales_dot_order__line__pb2.OrderLineReadRequest.SerializeToString,
            v1_dot_sales_dot_order__line__pb2.OrderLineReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OrderLineUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineUpdate",
            v1_dot_sales_dot_order__line__pb2.OrderLineUpdateRequest.SerializeToString,
            v1_dot_sales_dot_order__line__pb2.OrderLineUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OrderLineDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.order.line.OrderLineService/OrderLineDelete",
            v1_dot_sales_dot_order__line__pb2.OrderLineDeleteRequest.SerializeToString,
            v1_dot_sales_dot_order__line__pb2.OrderLineDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/picking_order.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.sales import order_pb2 as v1_dot_sales_dot_order__pb2
from omni.pro.protos.v1.sales import picking_pb2 as v1_dot_sales_dot_picking__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/sales/picking_order.proto\x12\'pro.omni.oms.api.v1.sales.picking.order\x1a\x11\x63ommon/base.proto\x1a\x16v1/sales/picking.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14v1/sales/order.proto"\xfb\x01\n\x0cPickingOrder\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x35\n\x05order\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12;\n\x07picking\x18\x03 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.picking.Picking\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"y\n\x19PickingOrderCreateRequest\x12\x10\n\x08order_id\x18\x01 \x01(\x05\x12\x12\n\npicking_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aPickingOrderCreateResponse\x12L\n\rpicking_order\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.sales.picking.order.PickingOrder\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17PickingOrderReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xef\x01\n\x18PickingOrderReadResponse\x12M\n\x0epicking_orders\x18\x01 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.sales.picking.order.PickingOrder\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\xa1\x01\n\x19PickingOrderUpdateRequest\x12L\n\rpicking_order\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.sales.picking.order.PickingOrder\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aPickingOrderUpdateResponse\x12L\n\rpicking_order\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.sales.picking.order.PickingOrder\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19PickingOrderDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aPickingOrderDeleteResponse\x12L\n\rpicking_order\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.sales.picking.order.PickingOrder\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x97\x05\n\x13PickingOrderService\x12\x9f\x01\n\x12PickingOrderCreate\x12\x42.pro.omni.oms.api.v1.sales.picking.order.PickingOrderCreateRequest\x1a\x43.pro.omni.oms.api.v1.sales.picking.order.PickingOrderCreateResponse"\x00\x12\x99\x01\n\x10PickingOrderRead\x12@.pro.omni.oms.api.v1.sales.picking.order.PickingOrderReadRequest\x1a\x41.pro.omni.oms.api.v1.sales.picking.order.PickingOrderReadResponse"\x00\x12\x9f\x01\n\x12PickingOrderUpdate\x12\x42.pro.omni.oms.api.v1.sales.picking.order.PickingOrderUpdateRequest\x1a\x43.pro.omni.oms.api.v1.sales.picking.order.PickingOrderUpdateResponse"\x00\x12\x9f\x01\n\x12PickingOrderDelete\x12\x42.pro.omni.oms.api.v1.sales.picking.order.PickingOrderDeleteRequest\x1a\x43.pro.omni.oms.api.v1.sales.picking.order.PickingOrderDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.picking_order_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PICKINGORDER"]._serialized_start = 171
    _globals["_PICKINGORDER"]._serialized_end = 422
    _globals["_PICKINGORDERCREATEREQUEST"]._serialized_start = 424
    _globals["_PICKINGORDERCREATEREQUEST"]._serialized_end = 545
    _globals["_PICKINGORDERCREATERESPONSE"]._serialized_start = 548
    _globals["_PICKINGORDERCREATERESPONSE"]._serialized_end = 729
    _globals["_PICKINGORDERREADREQUEST"]._serialized_start = 732
    _globals["_PICKINGORDERREADREQUEST"]._serialized_end = 1105
    _globals["_PICKINGORDERREADRESPONSE"]._serialized_start = 1108
    _globals["_PICKINGORDERREADRESPONSE"]._serialized_end = 1347
    _globals["_PICKINGORDERUPDATEREQUEST"]._serialized_start = 1350
    _globals["_PICKINGORDERUPDATEREQUEST"]._serialized_end = 1511
    _globals["_PICKINGORDERUPDATERESPONSE"]._serialized_start = 1514
    _globals["_PICKINGORDERUPDATERESPONSE"]._serialized_end = 1695
    _globals["_PICKINGORDERDELETEREQUEST"]._serialized_start = 1697
    _globals["_PICKINGORDERDELETEREQUEST"]._serialized_end = 1792
    _globals["_PICKINGORDERDELETERESPONSE"]._serialized_start = 1795
    _globals["_PICKINGORDERDELETERESPONSE"]._serialized_end = 1976
    _globals["_PICKINGORDERSERVICE"]._serialized_start = 1979
    _globals["_PICKINGORDERSERVICE"]._serialized_end = 2642
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class CalculateDeliveryMethodCoverageRequest(_message.Message):
    __slots__ = ["cart_details", "items", "shipping_details", "context"]
    CART_DETAILS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_DETAILS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    cart_details: _struct_pb2.Struct
    items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    shipping_details: _struct_pb2.Struct
    context: _base_pb2.Context
    def __init__(
        self,
        cart_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        shipping_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CalculateDeliveryMethodCoverageResponse(_message.Message):
    __slots__ = ["result", "response_standard"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    result: _struct_pb2.ListValue
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        result: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class CalculateDeliveryMethodAvailabilityRequest(_message.Message):
    __slots__ = ["cart_details", "items", "shipping_details", "context"]
    CART_DETAILS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_DETAILS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    cart_details: _struct_pb2.Struct
    items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    shipping_details: _struct_pb2.Struct
    context: _base_pb2.Context
    def __init__(
        self,
        cart_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        shipping_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CalculateDeliveryMethodAvailabilityResponse(_message.Message):
    __slots__ = ["result", "response_standard"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    result: _struct_pb2.Struct
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        result: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class CalculateDeliveryMethodTimeRequest(_message.Message):
    __slots__ = ["cart_details", "items", "shipping_details", "context"]
    CART_DETAILS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_DETAILS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    cart_details: _struct_pb2.Struct
    items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    shipping_details: _struct_pb2.Struct
    context: _base_pb2.Context
    def __init__(
        self,
        cart_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        shipping_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CalculateDeliveryMethodTimeResponse(_message.Message):
    __slots__ = ["result", "response_standard"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    result: _struct_pb2.ListValue
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        result: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class CalculateDeliveryMethodPriceRequest(_message.Message):
    __slots__ = ["cart_details", "items", "shipping_details", "context"]
    CART_DETAILS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_DETAILS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    cart_details: _struct_pb2.Struct
    items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    shipping_details: _struct_pb2.Struct
    context: _base_pb2.Context
    def __init__(
        self,
        cart_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        shipping_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class CalculateDeliveryMethodPriceResponse(_message.Message):
    __slots__ = ["result", "response_standard"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    result: _struct_pb2.ListValue
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        result: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...



from omni.pro.aws import AWSCloudMap
from omni.pro.config import Config


class CloudMap(AWSCloudMap):
    def __init__(self, service_name=Config.SERVICE_NAME, *args, **kwargs):
        cm_params = {
            "aws_access_key_id": Config.AWS_ACCESS_KEY_ID,
            "aws_secret_access_key": Config.AWS_SECRET_ACCESS_KEY,
            "region_name": Config.REGION_NAME,
            "service_name": service_name,
            "namespace_name": Config.NAMESPACE_NAME,
        }
        super().__init__(**cm_params, **kwargs)

    def get_url_channel(self, service_id):
        response = self.discover_instances()
        for instance in response:
            if instance.get("InstanceId") == service_id:
                host = instance.get("Attributes").get("host")
                port = instance.get("Attributes").get("port")
                return f"{host}:{port}"



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import carrier_pb2 as v1_dot_sales_dot_carrier__pb2


class CarrierServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CarrierCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierCreate",
            request_serializer=v1_dot_sales_dot_carrier__pb2.CarrierCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierCreateResponse.FromString,
        )
        self.CarrierRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierRead",
            request_serializer=v1_dot_sales_dot_carrier__pb2.CarrierReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierReadResponse.FromString,
        )
        self.CarrierUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierUpdate",
            request_serializer=v1_dot_sales_dot_carrier__pb2.CarrierUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierUpdateResponse.FromString,
        )
        self.CarrierDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierDelete",
            request_serializer=v1_dot_sales_dot_carrier__pb2.CarrierDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierDeleteResponse.FromString,
        )


class CarrierServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CarrierCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CarrierDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CarrierServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CarrierCreate": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierCreate,
            request_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_carrier__pb2.CarrierCreateResponse.SerializeToString,
        ),
        "CarrierRead": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierRead,
            request_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_carrier__pb2.CarrierReadResponse.SerializeToString,
        ),
        "CarrierUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierUpdate,
            request_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_carrier__pb2.CarrierUpdateResponse.SerializeToString,
        ),
        "CarrierDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CarrierDelete,
            request_deserializer=v1_dot_sales_dot_carrier__pb2.CarrierDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_carrier__pb2.CarrierDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.carrier.CarrierService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CarrierService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CarrierCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierCreate",
            v1_dot_sales_dot_carrier__pb2.CarrierCreateRequest.SerializeToString,
            v1_dot_sales_dot_carrier__pb2.CarrierCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierRead",
            v1_dot_sales_dot_carrier__pb2.CarrierReadRequest.SerializeToString,
            v1_dot_sales_dot_carrier__pb2.CarrierReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierUpdate",
            v1_dot_sales_dot_carrier__pb2.CarrierUpdateRequest.SerializeToString,
            v1_dot_sales_dot_carrier__pb2.CarrierUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CarrierDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.carrier.CarrierService/CarrierDelete",
            v1_dot_sales_dot_carrier__pb2.CarrierDeleteRequest.SerializeToString,
            v1_dot_sales_dot_carrier__pb2.CarrierDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/utilities/model.proto\x12#pro.omni.oms.api.v1.utilities.model\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xaf\x02\n\x05Model\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cmicroservice\x18\x02 \x01(\t\x12\x18\n\x10persistence_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x12\n\nclass_name\x18\x06 \x01(\t\x12\x11\n\thash_code\x18\x07 \x01(\t\x12:\n\x06\x66ields\x18\x08 \x03(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Field\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf8\x01\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x05\x12,\n\x08required\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x08relation\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06widget\x18\x08 \x01(\t\x12\x0c\n\x04view\x18\t \x01(\t\x12+\n\x07options\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue"\xfb\x01\n\x12ModelCreateRequest\x12\x14\n\x0cmicroservice\x18\x01 \x01(\t\x12\x18\n\x10persistence_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x12\n\nclass_name\x18\x05 \x01(\t\x12\x11\n\thash_code\x18\x06 \x01(\t\x12:\n\x06\x66ields\x18\x07 \x03(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Field\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13ModelCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model"\xee\x02\n\x10ModelReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd5\x01\n\x11ModelReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12:\n\x06models\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model"\x87\x01\n\x12ModelUpdateRequest\x12\x39\n\x05model\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13ModelUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model"X\n\x12ModelDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13ModelDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9c\x04\n\rModelsService\x12\x82\x01\n\x0bModelCreate\x12\x37.pro.omni.oms.api.v1.utilities.model.ModelCreateRequest\x1a\x38.pro.omni.oms.api.v1.utilities.model.ModelCreateResponse"\x00\x12|\n\tModelRead\x12\x35.pro.omni.oms.api.v1.utilities.model.ModelReadRequest\x1a\x36.pro.omni.oms.api.v1.utilities.model.ModelReadResponse"\x00\x12\x82\x01\n\x0bModelUpdate\x12\x37.pro.omni.oms.api.v1.utilities.model.ModelUpdateRequest\x1a\x38.pro.omni.oms.api.v1.utilities.model.ModelUpdateResponse"\x00\x12\x82\x01\n\x0bModelDelete\x12\x37.pro.omni.oms.api.v1.utilities.model.ModelDeleteRequest\x1a\x38.pro.omni.oms.api.v1.utilities.model.ModelDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.model_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_MODEL"]._serialized_start = 147
    _globals["_MODEL"]._serialized_end = 450
    _globals["_FIELD"]._serialized_start = 453
    _globals["_FIELD"]._serialized_end = 701
    _globals["_MODELCREATEREQUEST"]._serialized_start = 704
    _globals["_MODELCREATEREQUEST"]._serialized_end = 955
    _globals["_MODELCREATERESPONSE"]._serialized_start = 958
    _globals["_MODELCREATERESPONSE"]._serialized_end = 1113
    _globals["_MODELREADREQUEST"]._serialized_start = 1116
    _globals["_MODELREADREQUEST"]._serialized_end = 1482
    _globals["_MODELREADRESPONSE"]._serialized_start = 1485
    _globals["_MODELREADRESPONSE"]._serialized_end = 1698
    _globals["_MODELUPDATEREQUEST"]._serialized_start = 1701
    _globals["_MODELUPDATEREQUEST"]._serialized_end = 1836
    _globals["_MODELUPDATERESPONSE"]._serialized_start = 1839
    _globals["_MODELUPDATERESPONSE"]._serialized_end = 1994
    _globals["_MODELDELETEREQUEST"]._serialized_start = 1996
    _globals["_MODELDELETEREQUEST"]._serialized_end = 2084
    _globals["_MODELDELETERESPONSE"]._serialized_start = 2086
    _globals["_MODELDELETERESPONSE"]._serialized_end = 2182
    _globals["_MODELSSERVICE"]._serialized_start = 2185
    _globals["_MODELSSERVICE"]._serialized_end = 2725
# @@protoc_insertion_point(module_scope)



from google.protobuf import json_format
from omni.pro import redis
from omni.pro.descriptor import Descriptor
from omni.pro.logger import configure_logger
from omni.pro.protos.grpc_function import ModelRPCFucntion
from omni.pro.topology import Topology
from omni.pro.util import generate_hash

logger = configure_logger(name=__name__)


class RegisterModel(object):
    def __init__(self, models_path, microservice: str):
        self.models_path = models_path
        self.microservice = microservice

    def register_mongo_model(self):
        """
        Register MongoDB models.

        Registrar modelos MongoDB.
        """
        self._register("describe_mongo_model", "NO_SQL")

    def register_sqlalchemy_model(self):
        """
        Register SQLAlchemy models.

        Registrar modelos SQLAlchemy.
        """
        self._register("describe_sqlalchemy_model", "SQL")

    def _register(self, method: str, persistence_type: str):
        """
        Generic method to register models based on persistence type and descriptor method.

        Método genérico para registrar modelos basados en el tipo de persistencia y el método de descriptor.

        Parameters:
        ----------
        method : str
            Method name from Descriptor class to describe the model.
            Nombre del método de la clase Descriptor para describir el modelo.

        persistence_type : str
            Type of the persistence either "NO_SQL" or "SQL".
            Tipo de persistencia ya sea "NO_SQL" o "SQL".
        """
        redis_manager = redis.get_redis_manager()
        tenans = redis_manager.get_tenant_codes()
        models_libs = Topology(self.models_path).get_models_from_libs()
        for tenant in tenans:
            user = redis_manager.get_user_admin(tenant)
            context = {
                "tenant": tenant,
                "user": user.get("id") or "admin",
            }
            rpc_func = ModelRPCFucntion(context)
            for model in models_libs:
                desc = getattr(Descriptor, method)(model)
                desc = {"persistence_type": persistence_type, "microservice": self.microservice} | desc
                hash_code = generate_hash(desc)
                params = {
                    "filter": {
                        "filter": f"['and', ('microservice','=','{self.microservice}'), ('class_name','=','{desc.get('class_name')}')]"
                    }
                }
                response, success, event = rpc_func.read_model(params)
                if not success:
                    logger.warning(f"{event.get('rpc_method')}: {str(response.response_standard)}")
                    continue

                model = response.models[0] if response.models else None
                if model:
                    model_dict = self.transform_model_desc(model)
                    model_id = model_dict.pop("id")
                    if generate_hash(model_dict) == hash_code:
                        logger.info(f"Model {desc['class_name']} no changes")
                        continue

                    desc["hash_code"] = hash_code
                    params = {"model": {"id": model_id} | desc}
                    response, success, event = rpc_func.updated_model(params)
                else:
                    desc["hash_code"] = hash_code
                    params = desc
                    response, success, event = rpc_func.register_model(params)

                getattr(logger, "warning" if not success else "info")(
                    f"Model {desc['class_name']} method {event.get('rpc_method')} {str(response.response_standard)}"
                )

    def transform_model_desc(self, model):
        """
        Transform model description from proto message to dictionary.

        Transformar la descripción del modelo de mensaje proto a diccionario.

        Parameters:
        ----------
        model : object
            Proto message model description.
            Descripción del modelo de mensaje proto.

        Returns:
        -------
        dict
            Dictionary representation of the model description.
            Representación en diccionario de la descripción del modelo.
        """
        model_dict = json_format.MessageToDict(model, preserving_proto_field_name=True)
        return {
            "id": model_dict["id"],
            "persistence_type": model_dict["persistence_type"],
            "microservice": model_dict["microservice"],
            "name": model_dict["name"],
            "class_name": model_dict["class_name"],
            "code": model_dict["code"],
            "fields": [self.transform_field_desc(x) for x in model_dict["fields"]],
        }

    def transform_field_desc(self, field):
        """
        Transform field description from dictionary to specific format.

        Transformar la descripción del campo de diccionario a un formato específico.

        Parameters:
        ----------
        field : dict
            Dictionary representation of the field.
            Representación en diccionario del campo.

        Returns:
        -------
        dict
            Dictionary in the desired format for the field description.
            Diccionario en el formato deseado para la descripción del campo.
        """
        field_dict = {
            "name": field["name"],
            "code": field["code"],
            "type": field["type"],
            "required": field["required"],
            "relation": field["relation"],
        }
        if field.get("size"):
            field_dict["size"] = field["size"]
        if field.get("options"):
            field_dict["options"] = field["options"]
        return field_dict
